@@ -29,6 +29,7 @@
 
 #define SOUNDLISTFILE PACKAGE
 #define IMG_DATA_SET PACKAGE_DATA_DIR "/dataset/mrpatate.xml"
+#define FILE_SELECTOR_ROOT "drawings"
 
 /* Represent the drawing area */
 static gint drawing_area_x1 = 0;
@@ -54,22 +55,24 @@ static gboolean		 board_paused = TRUE;
 
 typedef enum
   {
-    TOOL_RECT		= 0,
-    TOOL_FILLED_RECT	= 1,
-    TOOL_CIRCLE		= 2,
-    TOOL_FILLED_CIRCLE	= 3,
-    TOOL_LINE		= 4,
-    TOOL_IMAGE		= 5,
-    TOOL_TEXT		= 6,
-    TOOL_GRID		= 7,
-    TOOL_DELETE		= 8,
-    TOOL_FILL		= 9,
-    TOOL_RAISE		= 10,
-    TOOL_LOWER		= 11,
-    TOOL_SELECT		= 12,
-    TOOL_FLIP		= 13,
-    TOOL_ROTATE_CCW	= 14,
-    TOOL_ROTATE_CW	= 15,
+    TOOL_SAVE		= 0,
+    TOOL_LOAD		= 1,
+    TOOL_RECT		= 2,
+    TOOL_FILLED_RECT	= 3,
+    TOOL_CIRCLE		= 4,
+    TOOL_FILLED_CIRCLE	= 5,
+    TOOL_LINE		= 6,
+    TOOL_IMAGE		= 7,
+    TOOL_TEXT		= 8,
+    TOOL_GRID		= 9,
+    TOOL_DELETE		= 10,
+    TOOL_FILL		= 11,
+    TOOL_RAISE		= 12,
+    TOOL_LOWER		= 13,
+    TOOL_SELECT		= 14,
+    TOOL_FLIP		= 15,
+    TOOL_ROTATE_CCW	= 16,
+    TOOL_ROTATE_CW	= 17,
   } ToolList;
 
 #define NUMBER_OF_TOOL	TOOL_ROTATE_CW + 1
@@ -81,6 +84,8 @@ static GnomeCanvasItem	*selectionToolItem = NULL;
 // Used to cross reference pixmap for the tools
 static char *tool_pixmap_name[] =
   {
+    "draw/tool-save.png",            "draw/tool-save.png",
+    "draw/tool-load.png",            "draw/tool-load.png",
     "draw/tool-rectangle.png",       "draw/tool-rectangle_on.png",
     "draw/tool-filledrectangle.png", "draw/tool-filledrectangle_on.png",
     "draw/tool-circle.png",          "draw/tool-circle_on.png",
@@ -94,7 +99,7 @@ static char *tool_pixmap_name[] =
     "draw/tool-up.png",              "draw/tool-up_on.png",
     "draw/tool-down.png",            "draw/tool-down_on.png",
     "draw/tool-select.png",          "draw/tool-select_on.png",
-    "draw/tool-flip.png",           "draw/tool-flip_on.png",
+    "draw/tool-flip.png",            "draw/tool-flip_on.png",
     "draw/tool-rotation-ccw.png",    "draw/tool-rotation-ccw_on.png",
     "draw/tool-rotation-cw.png",     "draw/tool-rotation-cw_on.png"
   };
@@ -150,7 +155,7 @@ static AnchorsItem *selected_anchors_item = NULL;
 
 #define DRAW_WIDTH_PIXELS	6
 
-#define GRID_COLOR		0x00000000
+#define GRID_COLOR		0XCECECEFF
 
 #define MAX_TEXT_CHAR		50
 
@@ -178,6 +183,8 @@ static void	 config(void);
 
 static void	 draw_destroy_all_items(void);
 static void	 draw_next_level(void);
+static ToolList	 get_tool(GnomeCanvasItem *item);
+static void	 create_anchors(GnomeCanvasItem *item);
 static void	 display_anchors(AnchorsItem *anchorsItem, gboolean visible);
 static void	 display_color_selector(GnomeCanvasGroup *parent);
 static void	 display_tool_selector(GnomeCanvasGroup *parent);
@@ -197,6 +204,8 @@ static guint	 get_resize_cursor(AnchorType anchor);
 static void	 realign_to_grid(GnomeCanvasItem *item);
 static void	 snap_to_grid(double *x, double *y);
 static void	 image_selected(gchar *image);
+static void	 load_drawing(gchar *file);
+static void	 save_drawing(gchar *file);
 
 /* Description of this plugin */
 static BoardPlugin menu_bp =
@@ -309,12 +318,15 @@ static gint key_press(guint keyval)
   if(!gcomprisBoard)
     return TRUE;
 
-  if(selected_anchors_item == NULL)
-    return TRUE;
-
   /* Add some filter for control and shift key */
   switch (keyval)
     {
+    case GDK_F1:
+      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, load_drawing);
+      break;
+    case GDK_F2:
+      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, save_drawing);
+      break;
     case GDK_Shift_L:
     case GDK_Shift_R:
     case GDK_Control_L:
@@ -365,6 +377,9 @@ static gint key_press(guint keyval)
       break;
     }
 
+  if(selected_anchors_item == NULL)
+    return TRUE;
+
   sprintf(utf8char, "%c", gdk_keyval_to_unicode(keyval));
 
   g_unichar_to_utf8 (gdk_keyval_to_unicode(keyval),
@@ -594,7 +609,7 @@ static void display_color_selector(GnomeCanvasGroup *parent)
   currentColor = ext_colorlist[0];
 }
 
-#define SELECTOR_VERTICAL_SPACING 55
+#define SELECTOR_VERTICAL_SPACING 52
 
 static void display_tool_selector(GnomeCanvasGroup *parent)
 {
@@ -630,15 +645,19 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
 				    "pixbuf", pixmap,
 				    "x", (double) x,
 				    "y", (double) y,
+				    "width", (double) 40.0,
+				    "height", (double) 40.0,
+				    "width_set", TRUE,
+				    "height_set", TRUE,
 				    NULL);
       gdk_pixbuf_unref(pixmap);
 
       gtk_signal_connect(GTK_OBJECT(item), "event",
 			 (GtkSignalFunc) tool_event,
-			 (void *)TOOL_RECT);
+			 (void *)TOOL_SAVE);
 
     }
-  currentTool = TOOL_RECT;
+  currentTool = TOOL_SAVE;
   currentToolItem = item;
 
   for( toolIndex = 1 ; toolIndex < NUMBER_OF_TOOL ; toolIndex++)
@@ -653,6 +672,10 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
 					"pixbuf", pixmap,
 					"x", (double) (toolIndex%2 == 0 ? x : x2),
 					"y", (double) y,
+					"width", (double) 40.0,
+					"height", (double) 40.0,
+					"width_set", TRUE,
+					"height_set", TRUE,
 					NULL);
 	  gdk_pixbuf_unref(pixmap);
 
@@ -908,6 +931,12 @@ tool_event(GnomeCanvasItem *item, GdkEvent *event, gint tool)
 
 	  switch(tool)
 	    {
+	    case TOOL_LOAD:
+	      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, load_drawing);
+	      break;
+	    case TOOL_SAVE:
+	      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, save_drawing);
+	      break;
 	    case TOOL_GRID:
 	      display_grid((grid_step==0 ? TRUE : FALSE));
 	      return TRUE;
@@ -986,51 +1015,54 @@ ext_color_event(GnomeCanvasItem *item, GdkEvent *event, gpointer color_rgba)
 
 static void display_anchors(AnchorsItem *anchorsItem, gboolean visible)
 {
+
+  g_assert(anchorsItem != NULL);
+
   if(visible)
     {
-      if(anchorsItem->nw)
+      if(anchorsItem->nw && GNOME_IS_CANVAS_RECT(anchorsItem->nw))
 	{
 	  gnome_canvas_item_show(anchorsItem->nw);
 	  gnome_canvas_item_raise_to_top(anchorsItem->nw);
 	}
 
-      if(anchorsItem->n)
+      if(anchorsItem->n && GNOME_IS_CANVAS_RECT(anchorsItem->n))
 	{
 	  gnome_canvas_item_show(anchorsItem->n);
 	  gnome_canvas_item_raise_to_top(anchorsItem->n);
 	}
 
-      if(anchorsItem->ne)
+      if(anchorsItem->ne && GNOME_IS_CANVAS_RECT(anchorsItem->ne))
 	{
 	  gnome_canvas_item_show(anchorsItem->ne);
 	  gnome_canvas_item_raise_to_top(anchorsItem->ne);
 	}
 
-      if(anchorsItem->w)
+      if(anchorsItem->w && GNOME_IS_CANVAS_RECT(anchorsItem->w))
 	{
 	  gnome_canvas_item_show(anchorsItem->w);
 	  gnome_canvas_item_raise_to_top(anchorsItem->w);
 	}
 
-      if(anchorsItem->e)
+      if(anchorsItem->e && GNOME_IS_CANVAS_RECT(anchorsItem->e))
 	{
 	  gnome_canvas_item_show(anchorsItem->e);
 	  gnome_canvas_item_raise_to_top(anchorsItem->e);
 	}
 
-      if(anchorsItem->sw)
+      if(anchorsItem->sw && GNOME_IS_CANVAS_RECT(anchorsItem->sw))
 	{
 	  gnome_canvas_item_show(anchorsItem->sw);
 	  gnome_canvas_item_raise_to_top(anchorsItem->sw);
 	}
 
-      if(anchorsItem->s)
+      if(anchorsItem->s && GNOME_IS_CANVAS_RECT(anchorsItem->s))
 	{
 	  gnome_canvas_item_show(anchorsItem->s);
 	  gnome_canvas_item_raise_to_top(anchorsItem->s);
 	}
 
-      if(anchorsItem->se)
+      if(anchorsItem->se && GNOME_IS_CANVAS_RECT(anchorsItem->se))
 	{
 	  gnome_canvas_item_show(anchorsItem->se);
 	  gnome_canvas_item_raise_to_top(anchorsItem->se);
@@ -1039,28 +1071,28 @@ static void display_anchors(AnchorsItem *anchorsItem, gboolean visible)
     }
   else
     {
-      if(anchorsItem->nw)
+      if(anchorsItem->nw && GNOME_IS_CANVAS_RECT(anchorsItem->nw))
 	gnome_canvas_item_hide(anchorsItem->nw);
 
-      if(anchorsItem->n)
+      if(anchorsItem->n && GNOME_IS_CANVAS_RECT(anchorsItem->n))
 	gnome_canvas_item_hide(anchorsItem->n);
 
-      if(anchorsItem->ne)
+      if(anchorsItem->ne && GNOME_IS_CANVAS_RECT(anchorsItem->ne))
 	gnome_canvas_item_hide(anchorsItem->ne);
 
-      if(anchorsItem->w)
+      if(anchorsItem->w && GNOME_IS_CANVAS_RECT(anchorsItem->w))
 	gnome_canvas_item_hide(anchorsItem->w);
 
-      if(anchorsItem->e)
+      if(anchorsItem->e && GNOME_IS_CANVAS_RECT(anchorsItem->e))
 	gnome_canvas_item_hide(anchorsItem->e);
 
-      if(anchorsItem->sw)
+      if(anchorsItem->sw && GNOME_IS_CANVAS_RECT(anchorsItem->sw))
 	gnome_canvas_item_hide(anchorsItem->sw);
 
-      if(anchorsItem->s)
+      if(anchorsItem->s && GNOME_IS_CANVAS_RECT(anchorsItem->s))
 	gnome_canvas_item_hide(anchorsItem->s);
 
-      if(anchorsItem->se)
+      if(anchorsItem->se && GNOME_IS_CANVAS_RECT(anchorsItem->se))
 	gnome_canvas_item_hide(anchorsItem->se);
     }
 }
@@ -1073,106 +1105,142 @@ static void reset_anchors_text(AnchorsItem *anchorsItem)
   gnome_canvas_item_get_bounds(anchorsItem->item,  &x1, &y1, &x2, &y2);
 
   if(anchorsItem->nw)
-  gnome_canvas_item_set (anchorsItem->nw,
-			 "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->nw,
+			   "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
 }
 
 static void reset_anchors_line(AnchorsItem *anchorsItem)
 {
+  GnomeCanvasItem *item;
+  double x1, x2, y1, y2;
+  double x, y;
+  GnomeCanvasPoints *points;
+
+  item = anchorsItem->item;
+
+  g_object_get(G_OBJECT(item), "points", &points, NULL);
+  if (points == NULL){
+    g_warning ("ERROR: LINE points NULL\n");
+    return;
+  }
+  x1 = points->coords[0];
+  y1 = points->coords[1];
+  x2 = points->coords[2];
+  y2 = points->coords[3];
 
   if(anchorsItem->nw)
-  gnome_canvas_item_set (anchorsItem->nw,
-			 "x1", (double) anchorsItem->ref_x1 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) anchorsItem->ref_y1 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) anchorsItem->ref_x1 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) anchorsItem->ref_y1 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->nw,
+			   "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->se)
-  gnome_canvas_item_set (anchorsItem->se,
-			 "x1", (double) anchorsItem->ref_x2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) anchorsItem->ref_y2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) anchorsItem->ref_x2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) anchorsItem->ref_y2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->se,
+			   "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
 }
 
 
 static void reset_anchors_bounded(AnchorsItem *anchorsItem)
 {
+  GnomeCanvasItem *item;
   double x1, x2, y1, y2;
 
-  gnome_canvas_item_get_bounds(anchorsItem->item,  &x1, &y1, &x2, &y2);
+  item = anchorsItem->item;
+
+  //gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2);
+
+  /* For each type of item, get the bounding box
+   * We do not use gnome_canvas_item_get_bounds because it creates lags
+   */
+  if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_RECT || 
+      G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_ELLIPSE) {
+
+    g_object_get(G_OBJECT(item), "x1", &x1, "y1", &y1, "x2", &x2, "y2", &y2, NULL);
+
+  } else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_PIXBUF ) {
+    double width, height;
+
+    g_object_get(G_OBJECT(item), "x", &x1, "y", &y1, NULL);
+    g_object_get(G_OBJECT(item), "width", &width, "height", &height, NULL);
+    x2 = x1 + width;
+    y2 = y1 + height;
+  }
 
   if(anchorsItem->nw)
-  gnome_canvas_item_set (anchorsItem->nw,
-			 "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->nw,
+			   "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->n)
-  gnome_canvas_item_set (anchorsItem->n,
-			 "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->n,
+			   "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->ne)
-  gnome_canvas_item_set (anchorsItem->ne,
-			 "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->ne,
+			   "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->e)
-  gnome_canvas_item_set (anchorsItem->e,
-			 "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y1+(y2-y1)/2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y1+(y2-y1)/2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->e,
+			   "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1+(y2-y1)/2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1+(y2-y1)/2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->w)
-  gnome_canvas_item_set (anchorsItem->w,
-			 "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y1+(y2-y1)/2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y1+(y2-y1)/2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->w,
+			   "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y1+(y2-y1)/2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y1+(y2-y1)/2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->sw)
-  gnome_canvas_item_set (anchorsItem->sw,
-			 "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->sw,
+			   "x1", (double) x1 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->se)
-  gnome_canvas_item_set (anchorsItem->se,
-			 "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->se,
+			   "x1", (double) x2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
   if(anchorsItem->s)
-  gnome_canvas_item_set (anchorsItem->s,
-			 "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
-			 "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
-			 "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
-			 "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
-			 NULL);
+    gnome_canvas_item_set (anchorsItem->s,
+			   "x1", (double) x1+(x2-x1)/2 - DEFAULT_ANCHOR_SIZE,
+			   "y1", (double) y2 - DEFAULT_ANCHOR_SIZE,
+			   "x2", (double) x1+(x2-x1)/2 + DEFAULT_ANCHOR_SIZE,
+			   "y2", (double) y2 + DEFAULT_ANCHOR_SIZE,
+			   NULL);
 
 }
 
@@ -1474,6 +1542,293 @@ static void set_item_color(AnchorsItem *anchorsItem, guint color)
     }
 }
 
+/*
+ * Given an item, return the tool as a ToolList used to create it
+ *
+ */
+static ToolList get_tool(GnomeCanvasItem *item)
+{
+  if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_GROUP )
+    return -1;
+  else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_RECT )
+    return TOOL_RECT;
+  else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_ELLIPSE )
+    return TOOL_CIRCLE;
+  else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_LINE )
+    return TOOL_LINE;
+  else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_TEXT )
+    return TOOL_TEXT;
+  else if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_PIXBUF )
+    return TOOL_IMAGE;
+
+  return -1;
+}
+
+/*
+ * Create the anchors
+ * (The item MUST BE in a group. The anchors are created in this group also)
+ */
+static void create_anchors(GnomeCanvasItem *item)
+{
+  GnomeCanvasGroup	*item_root_item = NULL;
+  GnomeCanvasItem	*anchorItem = NULL;
+  AnchorsItem		*anchorsItem = NULL;
+  ToolList		 currentTool;
+
+  g_assert(item != NULL);
+
+  item_root_item = GNOME_CANVAS_GROUP(item->parent);
+
+  /* Let the new item be on top */
+  gnome_canvas_item_raise_to_top(item);
+
+  currentTool = get_tool(item);
+
+  /* Create the Anchors */
+  anchorsItem = g_new0(AnchorsItem, 1);
+
+  anchorsItem->rootitem = GNOME_CANVAS_ITEM(item_root_item);
+  anchorsItem->item = item;
+  anchorsItem->tool = currentTool;
+
+
+  /*----------------------------------------*/
+  switch(currentTool)
+    {
+    case TOOL_LINE:
+      {
+	GnomeCanvasPoints* points = NULL;
+
+	// Keep track of the original size. It helps the resize operation for the line
+	g_object_get(G_OBJECT(item), "points", &points, NULL);
+	if (points == NULL){
+	  g_warning ("ERROR: LINE points NULL \n");
+	  return;
+	} else {
+	  anchorsItem->ref_x1 = points->coords[0];
+	  anchorsItem->ref_y1 = points->coords[1];
+	  anchorsItem->ref_x2 = points->coords[2];
+	  anchorsItem->ref_y2 = points->coords[3];
+	}
+
+	anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					    gnome_canvas_rect_get_type (),
+					    "fill_color_rgba", ANCHOR_COLOR,
+					    "outline_color", "black",
+					    "width_pixels", 1,
+					    NULL);
+	anchorsItem->nw = anchorItem;
+	gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
+	gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+	
+	gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+	/*----------------------------------------*/
+	anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					    gnome_canvas_rect_get_type (),
+					    "fill_color_rgba", ANCHOR_COLOR,
+					    "outline_color", "black",
+					    "width_pixels", 1,
+					    NULL);
+	anchorsItem->se = anchorItem;
+	gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SE);
+	gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+	gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			   (GtkSignalFunc) item_event_resize,
+			   anchorsItem);
+
+	anchorsItem->n  = NULL;
+	anchorsItem->s  = NULL;
+	anchorsItem->e  = NULL;
+	anchorsItem->w  = NULL;
+	anchorsItem->ne = NULL;
+	anchorsItem->sw = NULL;
+
+	reset_anchors_line(anchorsItem);
+	break;
+      }
+    case TOOL_IMAGE:
+    case TOOL_RECT:
+    case TOOL_CIRCLE:
+    case TOOL_FILLED_RECT:
+    case TOOL_FILLED_CIRCLE:
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->nw = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->n = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_N);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->ne = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NE);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->sw = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SW);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->s = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_S);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->se = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SE);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->w = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_W);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      /*----------------------------------------*/
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->e = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_E);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      reset_anchors_bounded(anchorsItem);
+      break;
+
+      /* Anchors is needed to show the text widget that has the focus */
+    case TOOL_TEXT:
+      anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
+					  gnome_canvas_rect_get_type (),
+					  "fill_color_rgba", ANCHOR_COLOR,
+					  "outline_color", "black",
+					  "width_pixels", 1,
+					  NULL);
+      anchorsItem->nw = anchorItem;
+      gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
+      gtk_object_set_data(GTK_OBJECT(anchorItem),"anchors", GINT_TO_POINTER(TRUE));
+
+      gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
+			 (GtkSignalFunc) item_event_resize,
+			 anchorsItem);
+
+      anchorsItem->n  = NULL;
+      anchorsItem->s  = NULL;
+      anchorsItem->e  = NULL;
+      anchorsItem->w  = NULL;
+      anchorsItem->ne = NULL;
+      anchorsItem->se = NULL;
+      anchorsItem->sw = NULL;
+
+      reset_anchors_text(anchorsItem);
+      break;
+
+    default:
+      /* No anchors in these cases */
+      anchorsItem->n  = NULL;
+      anchorsItem->s  = NULL;
+      anchorsItem->e  = NULL;
+      anchorsItem->w  = NULL;
+      anchorsItem->ne = NULL;
+      anchorsItem->sw = NULL;
+      anchorsItem->nw = NULL;
+      anchorsItem->se = NULL;
+      break;
+    }
+
+  if(selected_anchors_item)
+    display_anchors(selected_anchors_item, FALSE);
+
+  selected_anchors_item = anchorsItem;
+  display_anchors(anchorsItem, TRUE);
+
+  /* Move is performed on the item itself */
+  gtk_signal_connect(GTK_OBJECT(anchorsItem->rootitem), "event",
+		     (GtkSignalFunc) item_event_move,
+		     anchorsItem);
+}
+
 static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 {
   GnomeCanvasItem *item = NULL;
@@ -1511,6 +1866,10 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 				    "height_set", TRUE,
 				NULL);
       //				    "anchor", GTK_ANCHOR_CENTER,
+
+      /* Tell svg_save the filename */
+      gtk_object_set_data(GTK_OBJECT(item), "filename", g_strdup(imagename));
+
       gdk_pixbuf_unref(pixmap);
       break;
     case TOOL_RECT:
@@ -1524,9 +1883,8 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 				    "outline_color_rgba", currentColor,
 				    "width_pixels", DRAW_WIDTH_PIXELS,
 				    NULL);
-      /* FIXME : Was not needed in gnome1.2: needed in gnome 2                 */
-      /*         without it, at anchors creation, item bound is always 0,0,0,0 */
-      gnome_canvas_update_now (gcomprisBoard->canvas);
+      /* Tell svg_save this is a transparent item */
+      gtk_object_set_data(GTK_OBJECT(item),"empty", GINT_TO_POINTER(TRUE));
       break;
     case TOOL_FILLED_RECT:
       // This is a filled rectangle
@@ -1538,9 +1896,6 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 				    "y2", (double) y + item_size_y,
 				    "fill_color_rgba", currentColor,
 				    NULL);
-      /* FIXME : Was not needed in gnome1.2: needed in gnome 2                 */
-      /*         without it, at anchors creation, item bound is always 0,0,0,0 */
-      gnome_canvas_update_now (gcomprisBoard->canvas);
       break;
     case TOOL_CIRCLE:
       // This is an ellipse
@@ -1553,9 +1908,8 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 				    "outline_color_rgba", currentColor,
 				    "width_pixels", DRAW_WIDTH_PIXELS,
 				    NULL);
-      /* FIXME : Was not needed in gnome1.2: needed in gnome 2                 */
-      /*         without it, at anchors creation, item bound is always 0,0,0,0 */
-      gnome_canvas_update_now (gcomprisBoard->canvas);
+      /* Tell svg_save this is a transparent item */
+      gtk_object_set_data(GTK_OBJECT(item),"empty", GINT_TO_POINTER(TRUE));
       break;
     case TOOL_FILLED_CIRCLE:
       // This is a filled ellipse
@@ -1567,9 +1921,6 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 				    "y2", (double) y + item_size_y,
 				    "fill_color_rgba", currentColor,
 				    NULL);
-      /* FIXME : Was not needed in gnome1.2: needed in gnome 2                 */
-      /*         without it, at anchors creation, item bound is always 0,0,0,0 */
-      gnome_canvas_update_now (gcomprisBoard->canvas);
       break;
     case TOOL_LINE:
       // This is a line
@@ -1612,238 +1963,7 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
    */
   if(item)
     {
-      GnomeCanvasItem		*anchorItem = NULL;
-      AnchorsItem		*anchorsItem = NULL;
-
-      /* Let the new item be on top */
-      gnome_canvas_item_raise_to_top(item);
-
-      /* Create the Anchors */
-      anchorsItem = g_new(AnchorsItem, 1);
-
-      anchorsItem->rootitem = item_root_item;
-      anchorsItem->item = item;
-      anchorsItem->tool = currentTool;
-
-      // Keep track of the original size. It helps the resize operation for the line
-      if(points)
-	{
-	  anchorsItem->ref_x1 = points->coords[0];
-	  anchorsItem->ref_y1 = points->coords[1];
-	  anchorsItem->ref_x2 = points->coords[2];
-	  anchorsItem->ref_y2 = points->coords[3];
-	  gnome_canvas_points_unref(points);
-	}
-
-      /*----------------------------------------*/
-      switch(currentTool)
-	{
-	case TOOL_LINE:
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->nw = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->se = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SE);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  anchorsItem->n  = NULL;
-	  anchorsItem->s  = NULL;
-	  anchorsItem->e  = NULL;
-	  anchorsItem->w  = NULL;
-	  anchorsItem->ne = NULL;
-	  anchorsItem->sw = NULL;
-
-	  reset_anchors_line(anchorsItem);
-	  break;
-
-	case TOOL_IMAGE:
-	case TOOL_RECT:
-	case TOOL_CIRCLE:
-	case TOOL_FILLED_RECT:
-	case TOOL_FILLED_CIRCLE:
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->nw = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->n = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_N);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->ne = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NE);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->sw = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SW);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->s = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_S);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->se = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_SE);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->w = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_W);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  /*----------------------------------------*/
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->e = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_E);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  reset_anchors_bounded(anchorsItem);
-	  break;
-
-	  /* Anchors is needed to show the text widget that has the focus */
- 	case TOOL_TEXT:
-	  anchorItem = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
-					      gnome_canvas_rect_get_type (),
-					      "fill_color_rgba", ANCHOR_COLOR,
-					      "outline_color", "black",
-					      "width_pixels", 1,
-					      NULL);
-	  anchorsItem->nw = anchorItem;
-	  gtk_object_set_user_data(GTK_OBJECT(anchorItem), (void *)ANCHOR_NW);
-
-	  gtk_signal_connect(GTK_OBJECT(anchorItem), "event",
-			     (GtkSignalFunc) item_event_resize,
-			     anchorsItem);
-
-	  anchorsItem->n  = NULL;
-	  anchorsItem->s  = NULL;
-	  anchorsItem->e  = NULL;
-	  anchorsItem->w  = NULL;
-	  anchorsItem->ne = NULL;
-	  anchorsItem->se = NULL;
-	  anchorsItem->sw = NULL;
-
-	  reset_anchors_text(anchorsItem);
-	  break;
-
-	default:
-	  /* No anchors in these cases */
-	  anchorsItem->n  = NULL;
-	  anchorsItem->s  = NULL;
-	  anchorsItem->e  = NULL;
-	  anchorsItem->w  = NULL;
-	  anchorsItem->ne = NULL;
-	  anchorsItem->sw = NULL;
-	  anchorsItem->nw = NULL;
-	  anchorsItem->se = NULL;
-	  break;
-	}
-
-      if(selected_anchors_item)
-	display_anchors(selected_anchors_item, FALSE);
-
-      selected_anchors_item = anchorsItem;
-      display_anchors(anchorsItem, TRUE);
-
-      /* Move is performed on the item itself */
-      gtk_signal_connect(GTK_OBJECT(anchorsItem->rootitem), "event",
-			 (GtkSignalFunc) item_event_move,
-			 anchorsItem);
+      create_anchors(item);
     }
 
   return item;
@@ -2007,6 +2127,63 @@ static void image_selected(gchar *image)
   set_current_tool(selectionToolItem, TOOL_SELECT);
 }
 
+/*
+ * Recreate an item after it has been saved and is being reloaded
+ *
+ */
+static void recreate_item(GnomeCanvasItem *item)
+{
+
+  if(item == NULL) 
+    return;
+
+  if (G_OBJECT_TYPE(item) == GNOME_TYPE_CANVAS_GROUP ) {
+    /* If it's a group, then the first object is the real object to create the anchor for */
+    recreate_item(GNOME_CANVAS_ITEM(g_list_nth_data(GNOME_CANVAS_GROUP(item)->item_list, 0)));
+    return;
+  }
+
+  /* Rebuild the anchors */
+  create_anchors(item);
+}
+
+/**
+ * Callback for the drawing load
+ */
+static void load_drawing(gchar *file)
+{
+  printf("callback in draw, load_drawing got image %s\n", file);
+
+  /* Delete the current drawing */
+  /* WARNING: We should have a YES/NO Dialog box */
+  gtk_object_destroy (GTK_OBJECT(draw_root_item));
+  draw_root_item = \
+    gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
+			   gnome_canvas_group_get_type (),
+			   "x", (double)0,
+			   "y", (double)0,
+			   NULL);
+
+
+  gcompris_svg_restore(FILE_SELECTOR_ROOT, file, GNOME_CANVAS_GROUP(draw_root_item));
+
+  /* For each item we need to recreate the anchors */
+  g_list_foreach(GNOME_CANVAS_GROUP(draw_root_item)->item_list, (GFunc) recreate_item, NULL);
+
+  /* Set current_tool */
+  set_current_tool(selectionToolItem, TOOL_SELECT);
+
+}
+
+/**
+ * Callback for the drawing save
+ */
+static void save_drawing(gchar *file)
+{
+  printf("callback in draw, save_drawing got image %s\n", file);
+  gcompris_svg_save(FILE_SELECTOR_ROOT, file, draw_root_item, BOARDWIDTH, BOARDHEIGHT, 0);
+}
+
 /*
  * Special event callback for the move operation
  */
@@ -2091,12 +2268,12 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
 	    break;
 
 	  case TOOL_ROTATE_CW:
-	    item_rotate_relative(anchorsItem->item, 10);
+	    item_rotate_relative(anchorsItem->rootitem, 10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 
 	  case TOOL_ROTATE_CCW:
-	    item_rotate_relative(anchorsItem->item, -10);
+	    item_rotate_relative(anchorsItem->rootitem, -10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 
@@ -2136,11 +2313,11 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
 	  switch(currentTool) {
 	    /* Perform the reverse operation when it makes sense */
 	  case TOOL_ROTATE_CW:
-	    item_rotate_relative(anchorsItem->item, -10);
+	    item_rotate_relative(anchorsItem->rootitem, -10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 	  case TOOL_ROTATE_CCW:
-	    item_rotate_relative(anchorsItem->item, 10);
+	    item_rotate_relative(anchorsItem->rootitem, 10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 	  case TOOL_RAISE:
