@@ -56,23 +56,23 @@ static int number_of_item_max	= 0;
 // List of images to use in the game
 static gchar *imageList[] =
 {
-  "babyshapes/banana.png",
-  "babyshapes/circle.png",
-  "babyshapes/colonne.png",
-  "babyshapes/cone.png",
-  "babyshapes/coupole.png",
-  "babyshapes/cube.png",
-  "babyshapes/half_sphere.png",
-  "babyshapes/hexagone.png",
-  "babyshapes/hyperstar.png",
-  "babyshapes/losange.png",
-  "babyshapes/ovale.png",
-  "babyshapes/pacman.png",
-  "babyshapes/pyramid.png",
-  "babyshapes/rectangle.png",
-  "babyshapes/rectangle_triangle.png",
-  "babyshapes/sphere.png",
-  "babyshapes/star.png",
+  "gcompris/food/banana.png",
+  "gcompris/food/orange.png",
+  "gcompris/food/milk_shake.png",
+  "gcompris/food/pear.png",
+  "gcompris/food/grapefruit.png",
+  "gcompris/food/yahourt.png",
+  "gcompris/food/milk_cup.png",
+  "gcompris/food/suggar_box.png",
+  "gcompris/food/butter.png",
+  "gcompris/food/chocolate.png",
+  "gcompris/food/cookie.png",
+  "gcompris/food/french_croissant.png",
+  "gcompris/food/chocolate_cake.png",
+  "gcompris/food/marmelade.png",
+  "gcompris/food/baby_bottle.png",
+  "gcompris/food/bread_slice.png",
+  "gcompris/food/round_cookie.png",
 };
 #define NUMBER_OF_IMAGES 17
 
@@ -150,7 +150,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
 
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      "images/enumerate_background.jpg");
+			      "images/enumerate_background.png");
 
       enumerate_next_level();
 
