@@ -1,6 +1,6 @@
 /* gcompris - gletters.c
  *
- * Time-stamp: <2004/03/24 00:56:56 bcoudoin>
+ * Time-stamp: <2004/10/21 22:58:45 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -24,6 +24,7 @@
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
+#define MAX_RAND_ATTEMPTS 5
 
 static GList *item_list = NULL;
 static GList *item2del_list = NULL;
@@ -163,10 +164,8 @@ BoardPlugin
 static void level_set_score() {
   int l;
 
-#ifdef DEBUG
   g_message("letters_array length for level %d is %d\n",gcomprisBoard->level,
 	    g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1));
-#endif
   l = g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1)/3;
   gcomprisBoard->number_of_sublevel=(DEFAULT_SUBLEVEL>l?DEFAULT_SUBLEVEL:l);
 
@@ -212,17 +211,13 @@ static void pause_board (gboolean pause)
 }
 
 int fill_letters(char **letterString,char *buffer) {
-#ifdef DEBUG
   g_message("in fill_letters\n");
-#endif
   *letterString = g_malloc(strlen(buffer)+1);
   sprintf(*letterString,"%s",buffer);
 }
 
 int load_default_charset() {
-#ifdef DEBUG
   g_message("in load_default_charset\n");
-#endif
   fill_letters(&letters_array[0],"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
   fill_letters(&letters_array[1],"ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789");
   fill_letters(&letters_array[2],"abcdefghijklmnopqrstuvwxyz");
@@ -250,15 +245,11 @@ int load_charset_from_file(FILE *fp) {
   char lineBuffer[4096], strBuffer[4096], charBuffer[12];
 
   /* keymap size is dynamically allocated */
-#ifdef DEBUG
   g_message("scanning line\n");
-#endif
   keyMapSize = 64;
   currKeyMap = 0;
   keyMap = (char **)g_malloc((sizeof (char *))*keyMapSize);
-#ifdef DEBUG   
-  printf("in load_charset_from_file\n");
-#endif
+  g_warning("in load_charset_from_file\n");
   /* first read each line into a buffer */
   while( fgets(lineBuffer,4095,fp) ) {
     /* if it's a comment or blank (empty), skip line */
@@ -270,9 +261,7 @@ int load_charset_from_file(FILE *fp) {
      * fall rate, which starts with "fallrate" and format is "fallrate %f %f"
      * drop rate, which starts with "droprate" and format is "droprate %f %f"
      */
-#ifdef DEBUG
     g_message("scanning line\n");
-#endif
     if( sscanf(lineBuffer,"level %d %s",&level, strBuffer) == 2 ) {
       /* we have a level charset */
       if (level > MAXLEVEL || level < 1) {
@@ -281,9 +270,7 @@ int load_charset_from_file(FILE *fp) {
       }
       fill_letters(&letters_array[level-1],strBuffer);
       if(maxLevel < level) maxLevel = level;
-#ifdef DEBUG
       g_message("maxLevel: %d\n",maxLevel);
-#endif
     }
     else if( sscanf(lineBuffer,"key %11s",charBuffer) == 1) {
       /* we potentially have a keymap */
@@ -363,7 +350,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.jpg");
+      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
       get_charset(gcompris_get_locale());
       gcomprisBoard->maxlevel=maxLevel;
       gcomprisBoard->level = 1;
@@ -385,9 +372,7 @@ end_board ()
       pause_board(TRUE);
       gcompris_score_end();
       gletters_destroy_all_items();
-#ifdef DEBUG
       g_message("freeing memory");
-#endif      
       for (i = 0; i < maxLevel; i++) 
 	g_free(letters_array[i]);
 
@@ -438,10 +423,9 @@ static gint key_press(guint keyval) {
   gchar *str;
   char utf8char[6], keyChar[6], mapChar[6];
   int i;
+  gchar list_of_letters[255];
 
-#ifdef DEBUG
   g_message("in key_press: %d, %c, %lc",keyval,keyval,keyval);
-#endif
 
   if(!gcomprisBoard)
     return TRUE;
@@ -515,25 +499,19 @@ static gint key_press(guint keyval) {
      check direct match
      check upper case match
   */
-#ifdef DEBUG
   g_message("checking keymap: %d\n",keyMapSize);
-#endif
 
   i = g_unichar_to_utf8 (gdk_keyval_to_unicode(keyval),utf8char);
   utf8char[i]='\0';
 
 
   for (i = 0; i < keyMapSize; i++) {
-#ifdef DEBUG
     g_message("keymap: %d: %s\n",i,keyMap[i]);
-#endif
 
     sprintf(keyChar, "%lc", g_utf8_get_char(keyMap[i]));
     sprintf(mapChar, "%lc", g_utf8_get_char(g_utf8_find_next_char(keyMap[i], NULL)));
 
-#ifdef DEBUG
     g_message("char1: %s, char2: %s",keyChar, mapChar);
-#endif
 
     if (strcmp(utf8char, keyChar) == 0) {
 
@@ -546,23 +524,17 @@ static gint key_press(guint keyval) {
     }
   }
 
-#ifdef DEBUG
   g_message("no match-moving on\n");
-#endif
 
   /* no match in keymap */
   if (i == keyMapSize) {
 
-#ifdef DEBUG
     g_message("i == keyMapSize\n");
-#endif
 
     sprintf(lcStr,"%s",g_utf8_strdown(utf8char,-1));
     sprintf(ucStr,"%s",g_utf8_strup(utf8char,-1));
-#ifdef DEBUG
     g_message("lcStr = %s\n", lcStr);
     g_message("ucStr = %s\n", ucStr);
-#endif
     if ( is_falling_letter(lcStr) ) {
       str = lcStr;
     }
@@ -575,7 +547,6 @@ static gint key_press(guint keyval) {
     }
   }
 
-  gchar list_of_letters[255];
   list_of_letters[0] = '\0';
 
   /* We have to loop to concat the letters */
@@ -587,9 +558,7 @@ static gint key_press(guint keyval) {
 
   gcompris_log_set_comment(gcomprisBoard, list_of_letters, str);
 
-#ifdef DEBUG
   g_message("leaving key_press\n");
-#endif
 
   return TRUE;
 }
@@ -719,46 +688,50 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 {
   GdkPixbuf *gletters_pixmap = NULL;
   GnomeCanvasItem *item;
-  char *str  = NULL;
-  char *str2 = NULL;
-  int i,j,k;
+  gchar *str  = NULL;
+  gchar *str2 = NULL;
+  gint i,j,k;
   guint c, x;
-  char *lettersItem, *str_p;
+  gchar *lettersItem, *str_p;
 
   if (!letters_table)
     {
       letters_table= g_hash_table_new (g_str_hash, g_str_equal);
     }
 
-  lettersItem = g_malloc (6);
 
   /* Beware, since we put the letters in a hash table, we do not allow the same
      letter to be displayed two times 
-     WARNING : This can cause an infinite loop if there is not enough
-     element to choose
   */
 
-#ifdef DEBUG
-  printf("dump: %d, %s\n",gcomprisBoard->level,letters_array[gcomprisBoard->level-1]);
-#endif
+  g_warning("dump: %d, %s\n",gcomprisBoard->level,letters_array[gcomprisBoard->level-1]);
 
   k=g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1);
+
+  lettersItem = g_new(gchar,6);
+  gint attempt=0;
   do {
+
+    attempt++;
     str_p=letters_array[gcomprisBoard->level-1];
-    i=1+(int)((float)k*rand()/(RAND_MAX+1.0));
+    i=(int)((float)k*rand()/(RAND_MAX+1.0));
 
     for( j = 0; j < i; j++) {
       str_p=g_utf8_find_next_char(str_p,NULL);
     }
-    sprintf(lettersItem, "%lc",
-	    g_utf8_get_char(str_p));
 
-  } while(item_find_by_title(lettersItem)!=NULL);
+    g_utf8_strncpy (lettersItem, str_p,1);
 
-  str = g_strdup_printf("%s%s", lettersItem, ".ogg");
+  } while((attempt<MAX_RAND_ATTEMPTS) && (item_find_by_title(lettersItem)!=NULL));
+
+  if (item_find_by_title(lettersItem)!=NULL)  {g_free(lettersItem); return NULL;}
+
+  gchar *letter_no_caps=g_utf8_strdown(lettersItem,-1);
+  str = g_strdup_printf("%s%s", letter_no_caps, ".ogg");
   str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", str);
   gcompris_play_ogg(str2, NULL);
 
+  g_free(letter_no_caps);
   g_free(str);
   g_free(str2);
 
@@ -795,9 +768,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
   /* Add letter to hash table of all falling letters. */
   g_hash_table_insert (letters_table, lettersItem, item);
 
-#ifdef DEBUG
-  printf("done\n");
-#endif
+  g_warning("done\n");
 
   return (item);
 }
@@ -822,9 +793,7 @@ static gint gletters_drop_items (GtkWidget *widget, gpointer data)
 
 static void player_win(GnomeCanvasItem *item)
 {
-#ifdef DEBUG
   g_message("in player_win\n");
-#endif
 
   gletters_destroy_item(item);
   gcompris_play_ogg ("gobble", NULL);
@@ -863,21 +832,15 @@ static void player_win(GnomeCanvasItem *item)
 	  }
 	}
     }
-#ifdef DEBUG
-  printf("leaving player_win\n");
-#endif
+  g_warning("leaving player_win\n");
 }
 
 static void player_loose()
 {
-#ifdef DEBUG
-  printf("entering player_loose\n");
-#endif
+  g_warning("entering player_loose\n");
 
   gcompris_play_ogg ("crash", NULL);
-#ifdef DEBUG
-  printf("leaving player_loose\n");
-#endif
+  g_warning("leaving player_loose\n");
 }
 
 /* Return in item the key if the value equals the item */
