@@ -233,6 +233,23 @@ py_gcompris_dialog(PyObject* self, PyObject* args)
 }
 
 
+/* void	gcompris_dialog_close(); */
+static PyObject*
+py_gcompris_dialog_close(PyObject* self, PyObject* args)
+{
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, ":gcompris_dialog"))
+    return NULL;
+
+  /* Call the corresponding C function */
+  gcompris_dialog_close();
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+
 /* GdkPixbuf *gcompris_load_pixmap_asset(gchar *dataset, gchar* categories, */
 /*                                       gchar* mimetype, gchar* name);     */
 static PyObject*
@@ -279,6 +296,165 @@ py_gcompris_get_asset_file(PyObject* self, PyObject* args)
 }
 
 
+/* void gcompris_clone_item(GnomeCanvasItem *item, GnomeCanvasGroup *parent);*/
+static PyObject*
+py_gcompris_clone_item(PyObject* self, PyObject* args)
+{
+  PyObject* pyitem;
+  PyObject* pygroup;
+  GnomeCanvasItem* item;
+  GnomeCanvasGroup* group;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "OO:gcompris_clone_item", &pyitem, &pygroup))
+    return NULL;
+  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  group = (GnomeCanvasGroup*) pygobject_get(pygroup);
+
+  /* Call the corresponding C function */
+  gcompris_clone_item(item, group);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+
+/* void gcompris_svg_save(char *module, char *file, GnomeCanvasItem *item, int hsize, int vsize, int anim); */
+
+static PyObject*
+py_gcompris_svg_save(PyObject* self, PyObject* args)
+{
+  PyObject* pyitem;
+  GnomeCanvasItem* item;
+  char *module, *file;
+  int hsize, vsize, anim;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "ssOiii:gcompris_svg_save", &module, &file, &pyitem, &hsize, &vsize, &anim))
+    return NULL;
+  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+
+  /* Call the corresponding C function */
+  gcompris_svg_save(module, file, item, hsize, vsize, anim);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+
+/* void gcompris_svg_restore(char *module, char *filename, GnomeCanvasGroup *parent); */
+static PyObject*
+py_gcompris_svg_restore(PyObject* self, PyObject* args)
+{
+  PyObject* pygroup;
+  GnomeCanvasGroup* group;
+  char *filename, *module;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "ssO:gcompris_svg_restore", &module, &filename, &pygroup))
+    return NULL;
+  group = (GnomeCanvasGroup*) pygobject_get(pygroup);
+
+  /* Call the corresponding C function */
+  gcompris_svg_restore( module, filename, group);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+/* void filename_pass(PyObject *pyitem, PyObject *pystring) */
+static PyObject*
+py_gcompris_filename_pass(PyObject* self, PyObject* args)
+{
+  PyObject* pyitem;
+  GnomeCanvasItem *item;
+  char *string;
+
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "Os:gcompris_filename_pass", &pyitem, &string))
+    return NULL;
+
+  /* pass parameter from python */
+  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+
+  /* gcompris_filename_pass( item, string); */
+  g_object_set_data( G_OBJECT(item), "filename", string);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+
+}
+
+/*
+ * Set a property in a canvas object
+ * ---------------------------------
+ */
+/* void canvas_set_property(GnomeCanvasItem *item, gchar *property, gchar* value) */
+static PyObject*
+py_gcompris_canvas_set_property(PyObject* self, PyObject* args)
+{
+  PyObject* pyitem;
+  GnomeCanvasItem *item;
+  char *property;
+  char *value;
+
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "Oss:gcompris_canvas_set_property", &pyitem, &property, &value))
+    return NULL;
+
+  /* pass parameter from python */
+  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+
+  /* gcompris_filename_pass( item, string); */
+  g_object_set_data( G_OBJECT(item), property, value);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+
+}
+
+/*
+ * Get a property in a canvas object
+ * ---------------------------------
+ */
+/* gchar *canvas_get_property(GnomeCanvasItem *item, gchar *property) */
+static PyObject*
+py_gcompris_canvas_get_property(PyObject* self, PyObject* args)
+{
+  PyObject* pyitem;
+  GnomeCanvasItem *item;
+  char  *property;
+  char  *value;
+  gchar *result;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "Os:gcompris_canvas_get_property", &pyitem, &property))
+    return NULL;
+
+  /* pass parameter from python */
+  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+
+  /* gcompris_filename_pass( item, string); */
+  result = g_object_get_data( G_OBJECT(item), property);
+
+  /* Create and return the result */
+  if(result==NULL) {
+    Py_INCREF(Py_None);
+    return Py_None;
+  } else {
+    return Py_BuildValue("s", result);
+  }
+
+}
+
+
 static PyMethodDef PythonGcomprisUtilsModule[] = {
   { "load_pixmap",  py_gcompris_load_pixmap, METH_VARARGS, "gcompris_load_pixmap" },
   { "set_image_focus",  py_gcompris_set_image_focus, METH_VARARGS, "gcompris_set_image_focus" },
@@ -291,8 +467,15 @@ static PyMethodDef PythonGcomprisUtilsModule[] = {
   { "item_rotate_with_center",  py_gcompris_item_rotate_with_center, METH_VARARGS,
     "item_rotate_with_center" },
   { "dialog",  py_gcompris_dialog, METH_VARARGS, "gcompris_dialog" },
+  { "dialog_close",  py_gcompris_dialog_close, METH_VARARGS, "gcompris_dialog_close" },
   { "load_pixmap_asset",  py_gcompris_load_pixmap_asset, METH_VARARGS, "gcompris_load_pixmap_asset" },
   { "get_asset_file",  py_gcompris_get_asset_file, METH_VARARGS, "gcompris_get_asset_file" },
+  { "clone_item",  py_gcompris_clone_item, METH_VARARGS, "gcompris_clone_item" },
+  { "svg_save",  py_gcompris_svg_save, METH_VARARGS, "gcompris_svg_save" },
+  { "svg_restore",  py_gcompris_svg_restore, METH_VARARGS, "gcompris_svg_restore" },
+  { "filename_pass",  py_gcompris_filename_pass, METH_VARARGS, "gcompris_filename_pass" },
+  { "canvas_set_property",  py_gcompris_canvas_set_property, METH_VARARGS, "gcompris_canvas_set_property" },
+  { "canvas_get_property",  py_gcompris_canvas_get_property, METH_VARARGS, "gcompris_canvas_get_property" },
   { NULL, NULL, 0, NULL}
 };
 
