@@ -85,16 +85,13 @@ static GnomeCanvasItem *clock_image_item;
 // List of images to use in the game
 static gchar *imageList[] =
 {
-  "gcompris/animals/bear001.jpg",
-  "gcompris/animals/malaybear002.jpg",
-  "gcompris/animals/polabear011.jpg",
-  "gcompris/animals/joybear001.jpg",
-  "gcompris/animals/polarbear001.jpg",
-  "gcompris/animals/joybear002.jpg",
-  "gcompris/animals/flamentrosegc.jpg",
-  "gcompris/animals/girafegc.jpg",
-  "gcompris/animals/rhinogc.jpg",
-  "gcompris/animals/singegc.jpg",
+  "reversecount/baleine.png",
+  "reversecount/phoque.png",
+  "reversecount/ourspolaire.png",
+  "reversecount/morse.png",
+  "reversecount/elephant_mer.png",
+  "reversecount/epaulard.png",
+  "reversecount/narval.png",
 };
 #define NUMBER_OF_IMAGES 10
 
@@ -338,7 +335,7 @@ static void reversecount_next_level()
 {
 
   gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			  imageList[RAND(0, NUMBER_OF_IMAGES-1)]);
+			  imageList[gcomprisBoard->level-1]);
 
   gcompris_bar_set_level(gcomprisBoard);
 
@@ -520,7 +517,7 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
 
   //----------------------------------------
   // Create the dice area
-  pixmap = gcompris_load_pixmap("reversecount/dice_area.jpg");
+  pixmap = gcompris_load_pixmap("reversecount/dice_area.png");
 
   dice_area_x = BOARDWIDTH - block_width - gdk_pixbuf_get_width (pixmap) - 20;
 
@@ -542,7 +539,7 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
       int *val;
 
       i = dice_area_x + gdk_pixbuf_get_width(pixmap) * d + 30;
-      j = block_height + 25;
+      j = block_height + 25 + d*7;
 
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
@@ -605,21 +602,21 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
   if(block < number_of_item_x)
     {
       // Upper line
-      printf("      // Upper line\n");
+      g_warning("      // Upper line\n");
       i = block_width * block;
       j = 0;
     } 
   else if(block < number_of_item_x + number_of_item_y - 2)
     {
       // Right line
-      printf("      // Right line\n");
+      g_warning("      // Right line\n");
       i = block_width * (number_of_item_x - 1);
       j = block_height * (block - (number_of_item_x-1));
     }
   else if(block < number_of_item_x*2 + number_of_item_y - 2)
     {
       // Bottom line
-      printf("      // Bottom line\n");
+      g_warning("      // Bottom line\n");
       i = block_width * (number_of_item_x - (block-
 					     (number_of_item_x+number_of_item_y-1))-2);
       j = block_height * (number_of_item_y-1);
@@ -627,13 +624,13 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
   else
     {
       // Left line
-      printf("      // Left line\n");
+      g_warning("      // Left line\n");
       i = 0;
       j = block_height * (number_of_item_y - (block - (number_of_item_x*2 + 
 						      number_of_item_y-4)));
     }
 
-  printf("display_tux %d i=%d j=%d\n", block, i, j);
+  g_warning("display_tux %d i=%d j=%d\n", block, i, j);
 
   /* Calculation to thrink the item while keeping the ratio */
   if(ratio==-1)
@@ -791,7 +788,7 @@ static gint animate_tux()
 
   tux_index++;
 
-  printf("=========== tux_index=%d tux_destination=%d fish_index=%d\n", tux_index, tux_destination, fish_index);
+  g_warning("=========== tux_index=%d tux_destination=%d fish_index=%d\n", tux_index, tux_destination, fish_index);
 
   // Wrapping
   if(tux_index >= number_of_item)
