@@ -1,6 +1,6 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2004/06/15 01:33:41 bcoudoin>
+ * Time-stamp: <2004/11/09 00:29:43 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -59,6 +59,7 @@ typedef enum
 typedef struct _Shape Shape;
 struct _Shape {
   char  *name;				/* name of the shape */
+  char  *tooltip;			/* optional tooltip for the shape */
   char  *pixmapfile;			/* relative pixmap file name of the shape */
   GnomeCanvasPoints* points; 		/* OR list of points for this shape */
   char  *targetfile;			/* OPTIONAL relative pixmap file name of the target shape, by default 
@@ -106,8 +107,8 @@ static GList *shape_list	= NULL;
 static GList *shape_list_group	= NULL;
 static int current_shapelistgroup_index	= -1;
 
-static GnomeCanvasItem *next_shapelist_item;		/* Canvas item button for the next shapelist */
-static GnomeCanvasItem *previous_shapelist_item;   	/* Canvas item button for the previous shapelist */
+static GnomeCanvasItem *next_shapelist_item     = NULL;		/* Canvas item button for the next shapelist */
+static GnomeCanvasItem *previous_shapelist_item = NULL;   	/* Canvas item button for the previous shapelist */
 
 /* Let's define the structure for the shapebox list that contains the icons of the shapes */
 typedef struct _ShapeBox ShapeBox;
@@ -130,6 +131,11 @@ static gint SHAPE_BOX_WIDTH_RATIO = 18;
 static GnomeCanvasItem	*shape_root_item;
 static GnomeCanvasItem	*shape_list_root_item;
 
+/* The tooltip */
+static GnomeCanvasGroup	*tooltip_root_item;
+static GnomeCanvasItem	*tooltip_text_item;
+static GnomeCanvasItem	*tooltip_bg_item;
+
 static void		 start_board (GcomprisBoard *agcomprisBoard);
 static void 		 pause_board (gboolean pause);
 static void 		 end_board (void);
@@ -138,18 +144,20 @@ static void 		 set_level (guint level);
 static void 		 process_ok(void);
 static gint		 key_press(guint keyval);
 
-static GnomeCanvasItem 	*shapegame_init_canvas(GnomeCanvasGroup *parent);
+static void              shapegame_init_canvas(GnomeCanvasGroup *parent);
 static void 		 shapegame_destroy_all_items(void);
 static void 		 setup_item(GnomeCanvasItem *item, Shape *shape);
 static void 		 shapegame_next_level(void);
 static gboolean 	 read_xml_file(char *fname);
 static gboolean 	 write_xml_file(char *fname);
 static Shape 		*find_closest_shape(double x, double y, double limit);
-static Shape 		*create_shape(ShapeType type, char *name, char *pixmapfile,  GnomeCanvasPoints* points,
+static Shape 		*create_shape(ShapeType type, char *name, char *tooltip,
+				      char *pixmapfile,  GnomeCanvasPoints* points,
 				      char *targetfile, double x, double y, double l, double h, double zoomx, 
 				      double zoomy, guint position, char *soundfile);
 static gboolean 	 increment_sublevel(void);
-static void 		 create_title(char *name, double x, double y, GtkJustification justification);
+static void 		 create_title(char *name, double x, double y, GtkJustification justification,
+				      guint32 color_rgba);
 static gint		 item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
 static gint		 item_event_edition(GnomeCanvasItem *item, GdkEvent *event, Shape *shape);
 
@@ -556,12 +564,12 @@ static void process_ok()
 	Shape *shape = list->data;
 	gint   intname = 0;
 
-	printf("   shape = %s\n", shape->name);
+	g_warning("   shape = %s\n", shape->name);
 	if(shape->type==SHAPE_TARGET && shape->placed==TRUE)
 	  {
 	    intname = atoi(shape->name);
 	    total += intname;
-	    printf("      shape = %s   placed=TRUE\n", shape->name);
+	    g_warning("      shape = %s   placed=TRUE\n", shape->name);
 	  }
 
       }
@@ -569,7 +577,7 @@ static void process_ok()
       if(total != addedname)
 	done = FALSE;
 
-      printf("checking for addedname=%d done=%d total=%d\n", addedname, done, total);
+      g_warning("checking for addedname=%d done=%d total=%d\n", addedname, done, total);
     }
 
 
@@ -617,6 +625,8 @@ static void shapegame_destroy_all_items()
       shape_list_root_item = NULL;
       gtk_object_destroy (GTK_OBJECT(shape_root_item));
       shape_root_item = NULL;
+      gtk_object_destroy (GTK_OBJECT(tooltip_root_item));
+      tooltip_root_item = NULL;
 
       g_hash_table_destroy (shapelist_table);
       shapelist_table=NULL;
@@ -627,10 +637,9 @@ static void shapegame_destroy_all_items()
     }
 }
 
-static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent)
+static void shapegame_init_canvas(GnomeCanvasGroup *parent)
 {
-  GnomeCanvasItem *item = NULL;
-
+  GdkPixbuf       *pixmap = NULL;
 
   shape_list_root_item = \
     gnome_canvas_item_new (parent,
@@ -646,7 +655,40 @@ static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent)
 			   "y", (double)0,
 			   NULL);
 
-  return (item);
+  /* Create the tooltip area */
+  pixmap = gcompris_load_skin_pixmap("button_large.png");
+  tooltip_root_item = GNOME_CANVAS_GROUP(
+					 gnome_canvas_item_new (parent,
+								gnome_canvas_group_get_type (),
+								"x", (double)gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO + 60,
+								"y", (double)0,
+								NULL)
+					 );
+
+  tooltip_bg_item = \
+    gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
+			   gnome_canvas_pixbuf_get_type (),
+			   "pixbuf", pixmap, 
+			   "x", (double) 0,
+			   "y", (double) 0,
+			   NULL);
+  gdk_pixbuf_unref(pixmap);
+
+  tooltip_text_item = \
+    gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
+			   gnome_canvas_text_get_type (),
+			   "text", "",
+			   "font", gcompris_skin_font_board_small,
+			   "x", (double)gdk_pixbuf_get_width(pixmap)/2,
+			   "y", 24.0,
+			   "anchor", GTK_ANCHOR_CENTER,
+			   "justification", GTK_JUSTIFY_CENTER,
+			   "fill_color_rgba", gcompris_skin_color_text_button,
+			   NULL);
+
+  /* Hide the tooltip */
+  gnome_canvas_item_hide(GNOME_CANVAS_ITEM(tooltip_root_item));
+
 }
 
 /**************************************************************
@@ -714,13 +756,13 @@ add_shape_to_list_of_shapes(Shape *shape)
   if(g_hash_table_size(shapelist_table)%(shapeBox.nb_shape_x * shapeBox.nb_shape_y)==0)
     {
       current_shapelistgroup_index++;
-      printf("Creation of the group of shape current_shapelistgroup_index=%d\n", 
+      g_warning("Creation of the group of shape current_shapelistgroup_index=%d\n", 
 	     current_shapelistgroup_index);
 
       // Hide the previous group
       if(current_shapelistgroup_index>=1)
 	{
-	  printf(" Hide previous group\n");
+	  g_warning(" Hide previous group\n");
 	  shape_list_group_root = GNOME_CANVAS_GROUP(g_list_nth_data(shape_list_group, 
 								     current_shapelistgroup_index-1));
 	  //gnome_canvas_item_hide(shape_list_group_root);
@@ -737,13 +779,13 @@ add_shape_to_list_of_shapes(Shape *shape)
 						 NULL));
 
       shape_list_group = g_list_append (shape_list_group, shape_list_group_root);
-      printf(" current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
+      g_warning(" current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
 
     }
   else
     {
       // Get the current shapelist group
-      printf(" get the current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
+      g_warning(" get the current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
       shape_list_group_root = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
     }
 
@@ -764,8 +806,8 @@ add_shape_to_list_of_shapes(Shape *shape)
 				 ( shapeBox.nb_shape_x * shapeBox.nb_shape_y)) /
 				shapeBox.nb_shape_y) *
 			       ICON_WIDTH);
-      printf("  ICON_WIDTH = %f   ICON_HEIGHT = %f\n", ICON_WIDTH, ICON_HEIGHT);
-      printf("x_offset = %f   y_offset = %f\n", x_offset, y_offset);
+      g_warning("  ICON_WIDTH = %f   ICON_HEIGHT = %f\n", ICON_WIDTH, ICON_HEIGHT);
+      g_warning("x_offset = %f   y_offset = %f\n", x_offset, y_offset);
 
       /* So this shape is not yet in, let's put it in now */
       g_hash_table_insert (shapelist_table, shape->pixmapfile, shape);
@@ -802,7 +844,7 @@ add_shape_to_list_of_shapes(Shape *shape)
 					    NULL);
 	      gdk_pixbuf_unref(pixmap);
 	      
-	      icon_shape = create_shape(SHAPE_ICON, shape->name, 
+	      icon_shape = create_shape(SHAPE_ICON, shape->name, shape->tooltip,
 					shape->pixmapfile, shape->points, shape->targetfile,
 					(double)0, (double)y_offset,
 					(double)w, (double)h, 
@@ -812,7 +854,7 @@ add_shape_to_list_of_shapes(Shape *shape)
 	      icon_shape->target_shape = shape;
 	      icon_shape->shapelistgroup_index = current_shapelistgroup_index;
 	      shape->shapelistgroup_index = current_shapelistgroup_index;
-	      printf(" creation shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", 
+	      g_warning(" creation shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", 
 		     shape->name, 
 		     shape->shapelistgroup_index, current_shapelistgroup_index);
 	      icon_shape->shape_list_group_root = shape_list_group_root;
@@ -844,8 +886,8 @@ static Shape *find_closest_shape(double x, double y, double limit)
       {
 	/* Calc the distance between this shape and the given coord */
 	dist = sqrt(pow((shape->x-x),2) + pow((shape->y-y),2));
-	printf("DIST=%f shapename=%s\n", dist, shape->name);
-	printf("   x=%f y=%f shape->x=%f shape->y=%f\n", x, y, shape->x, shape->y);
+	g_warning("DIST=%f shapename=%s\n", dist, shape->name);
+	g_warning("   x=%f y=%f shape->x=%f shape->y=%f\n", x, y, shape->x, shape->y);
 	if(dist<goodDist)
 	  {
 	    goodDist=dist;
@@ -860,12 +902,12 @@ static Shape *find_closest_shape(double x, double y, double limit)
 //#if 0
 static void dump_shape(Shape *shape)
 {
-  printf("dump_shape name=%s found=%d type=%d ", shape->name, shape->found, shape->type);
+  g_warning("dump_shape name=%s found=%d type=%d ", shape->name, shape->found, shape->type);
   if(shape->bad_item)
-    printf("bad_item=TRUE ");
+    g_warning("bad_item=TRUE ");
   if(shape->icon_shape)
-    printf("icon_shape=%s", shape->icon_shape->name);
-  printf("\n");
+    g_warning("icon_shape=%s", shape->icon_shape->name);
+  g_warning("\n");
 }
 //#endif
 
@@ -875,14 +917,14 @@ static void dump_shape(Shape *shape)
  */
 static void shape_goes_back_to_list(Shape *shape, GnomeCanvasItem *item)
 {
-  printf("shape_goes_back_to_list shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", shape->name, shape->shapelistgroup_index, current_shapelistgroup_index);
+  g_warning("shape_goes_back_to_list shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", shape->name, shape->shapelistgroup_index, current_shapelistgroup_index);
 
   if(shape->icon_shape!=NULL)
     {
       if(shape->icon_shape->target_shape)
 	{
 	  shape->icon_shape->target_shape->placed = FALSE;
-	  printf("shape_goes_back_to_list setting shape->name=%s to placed=%d\n", 
+	  g_warning("shape_goes_back_to_list setting shape->name=%s to placed=%d\n", 
 		 shape->icon_shape->target_shape->name,
 		 shape->icon_shape->target_shape->placed);
 	}
@@ -938,6 +980,25 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 
    switch (event->type) 
      {
+     case GDK_ENTER_NOTIFY:
+       if(shape->tooltip && shape->type == SHAPE_ICON) {
+	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_root_item),
+			       "y", shape->y,
+			       NULL);
+	 /* WARNING: This should not be needed but if I don't do it, it's not refreshed */
+	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_bg_item),
+			       "y", 0.0,
+			       NULL);
+	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_text_item),
+			       "text", shape->tooltip,
+			       NULL);
+	 gnome_canvas_item_show(GNOME_CANVAS_ITEM(tooltip_root_item));
+       }
+       break;
+     case GDK_LEAVE_NOTIFY:
+       if(shape->tooltip && shape->type == SHAPE_ICON)
+       	 gnome_canvas_item_hide(GNOME_CANVAS_ITEM(tooltip_root_item));
+       break;
      case GDK_BUTTON_PRESS:
        switch(event->button.button) 
          {
@@ -956,7 +1017,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 	       switch(shape->type)
 		 {
 		 case SHAPE_TARGET:
-		   gnome_canvas_item_hide(item);
+		   gnome_canvas_item_hide(GNOME_CANVAS_ITEM(item));
 		   gcompris_set_image_focus(item, FALSE);
 
 		   if( shape->icon_shape!=NULL)
@@ -989,7 +1050,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 			 *p='\0';
 			 gcompris_play_ogg(soundfile, NULL);
 			 soundfile=p+1;
-			 printf("soundfile = %s\n", soundfile);
+			 g_warning("soundfile = %s\n", soundfile);
 		       }
 
 		     gcompris_play_ogg(soundfile, NULL);
@@ -1002,7 +1063,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 	       /* This records the offset between the mouse pointer and the grabbed item center */
 	       offset_x = x - item_x;
 	       offset_y = y - item_y;
-	       printf("offsetx=%f offsetx=%f\n", offset_x, offset_y);
+	       g_warning("offsetx=%f offsetx=%f\n", offset_x, offset_y);
 	       if(item==NULL)
 		 return FALSE;
 	       
@@ -1078,7 +1139,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		     }
 		   targetshape->found  = TRUE;
 		   shape->target_shape->placed = TRUE;
-		   printf("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
+		   g_warning("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
 			  shape->target_shape->placed);
 		   gnome_canvas_item_show(targetshape->item);
 		   gnome_canvas_item_raise_to_top(targetshape->item);
@@ -1091,7 +1152,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 
 		   targetshape->found = FALSE;
 		   shape->target_shape->placed = TRUE;
-		   printf("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
+		   g_warning("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
 			  shape->target_shape->placed);
 		   gnome_canvas_item_hide(targetshape->item);
 
@@ -1276,15 +1337,11 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
   switch (event->type) 
     {
-    case GDK_ENTER_NOTIFY:
-      break;
-    case GDK_LEAVE_NOTIFY:
-      break;
     case GDK_BUTTON_PRESS:
       root_item = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
       gnome_canvas_item_hide(root_item);
 
-      printf(" item event current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
+      g_warning(" item event current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
       if(!strcmp((char *)data, "previous_shapelist"))
 	{
 
@@ -1323,7 +1380,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       gnome_canvas_item_show(root_item);
 
       /* FIXME : Workaround for bugged canvas */
-      gnome_canvas_update_now(gcomprisBoard->canvas);
+      //      gnome_canvas_update_now(gcomprisBoard->canvas);
 
     default:
       break;
@@ -1380,16 +1437,18 @@ add_shape_to_canvas(Shape *shape)
 	}
       else
 	{
+	  int point_size = 6;
+
 	  /* Display a point to highlight the target location of this shape */
 	  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
 					gnome_canvas_ellipse_get_type(),
-					"x1", (double)shape->x-2.5,
-					"y1", (double)shape->y-2.5,
-					"x2", (double)shape->x+2.5,
-					"y2", (double)shape->y+2.5,
+					"x1", (double)shape->x-point_size,
+					"y1", (double)shape->y-point_size,
+					"x2", (double)shape->x+point_size,
+					"y2", (double)shape->y+point_size,
 					"fill_color_rgba", 0xEf000080,
 					"outline_color", "black",
-					"width_pixels", 0,
+					"width_pixels", 2,
 					NULL);
 	  shape->target_point = item;
 	  gtk_signal_connect(GTK_OBJECT(item), "event",
@@ -1401,7 +1460,7 @@ add_shape_to_canvas(Shape *shape)
   
   if(shape->points!=NULL)
     {
-      printf("it's a point \n");
+      g_warning("it's a point \n");
       item = gnome_canvas_item_new(GNOME_CANVAS_GROUP(shape_root_item),
 				   gnome_canvas_polygon_get_type (),
 				   "points", shape->points,
@@ -1412,10 +1471,10 @@ add_shape_to_canvas(Shape *shape)
     }
   else
     {
-      printf("it's an image ? shape->pixmapfile=%s\n", shape->pixmapfile);
+      g_warning("it's an image ? shape->pixmapfile=%s\n", shape->pixmapfile);
       if(strcmp(shape->pixmapfile, UNDEFINED)!=0)
 	{
-	  printf("  Yes it is an image \n");
+	  g_warning("  Yes it is an image \n");
 	  pixmap = gcompris_load_pixmap(shape->pixmapfile);
 	  if(pixmap)
 	    {
@@ -1456,7 +1515,8 @@ add_shape_to_canvas(Shape *shape)
 
 }
 
-static void create_title(char *name, double x, double y, GtkJustification justification)
+static void create_title(char *name, double x, double y, GtkJustification justification,
+			 guint32 color_rgba)
 {
   GnomeCanvasItem *item;
 
@@ -1484,14 +1544,14 @@ static void create_title(char *name, double x, double y, GtkJustification justif
 			   "y", y,
 			   "anchor", GTK_ANCHOR_CENTER,
 			   "justification", justification,
-			   "fill_color", "white",
+			   "fill_color_rgba", color_rgba,
 			   NULL);
 
   gnome_canvas_item_raise_to_top(item);
 }
 
 static Shape *
-create_shape(ShapeType type, char *name, char *pixmapfile, GnomeCanvasPoints* points,
+create_shape(ShapeType type, char *name, char *tooltip, char *pixmapfile, GnomeCanvasPoints* points,
 	     char *targetfile, double x, double y, 
 	     double w, double h, double zoomx, 
 	     double zoomy, guint position, char *soundfile)
@@ -1502,6 +1562,11 @@ create_shape(ShapeType type, char *name, char *pixmapfile, GnomeCanvasPoints* po
   shape = g_new(Shape,1);
   
   shape->name = g_strdup(name);
+  if(tooltip)
+    shape->tooltip = g_strdup(tooltip);
+  else
+    shape->tooltip = NULL;
+
   shape->pixmapfile = g_strdup(pixmapfile);
   shape->points = points;
   shape->targetfile = g_strdup(targetfile);
@@ -1533,6 +1598,7 @@ static void
 add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
   char *name, *cx, *cy, *cd, *czoomx, *czoomy, *cposition, *ctype, *justification;
+  char *tooltip;
   GtkJustification justification_gtk;
   char *pixmapfile = NULL;
   char *targetfile = NULL;
@@ -1546,6 +1612,8 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   Shape *shape;
   xmlNodePtr xmlnamenode;
   char *locale;
+  char *color_text;
+  guint color_rgba;
 
   if(/* if the node has no name */
      !xmlnode->name ||
@@ -1560,7 +1628,16 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   
   pixmapfile = xmlGetProp(xmlnode,"pixmapfile");
   /* if unspecified, make it UNDEFINED */
-  if(!pixmapfile) pixmapfile = UNDEFINED;
+  if(!pixmapfile) {
+    pixmapfile = UNDEFINED;
+  } else {
+    /* If the pixmapfile starts with skin: then get the skin relative image instead */
+    if(!strncmp(pixmapfile, "skin:", 5)) {
+      gchar *oldpixmapfile = pixmapfile;
+      pixmapfile = gcompris_image_to_skin(oldpixmapfile+5);
+      g_free(oldpixmapfile);
+    }
+  }
 
   targetfile = xmlGetProp(xmlnode,"targetfile");
   /* if unspecified, make it UNDEFINED */
@@ -1662,8 +1739,17 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
     }
   }
 
-  /* get the name of the shape */
-  name = NULL;
+  /* get the COLOR of the Title Specified by skin reference */
+  color_text = xmlGetProp(xmlnode,"color_skin");
+  if(color_text) {
+    color_rgba = gcompris_skin_get_color(color_text);
+  } else {
+    color_rgba = gcompris_skin_get_color("gcompris/content");	/* the default */
+  }
+
+  /* get the name and tooltip of the shape */
+  name    = NULL;
+  tooltip = NULL;
 
   xmlnamenode = xmlnode->xmlChildrenNode;
   while (xmlnamenode != NULL) {
@@ -1676,6 +1762,16 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
       {
 	name = xmlNodeListGetString(doc, xmlnamenode->xmlChildrenNode, 1);
       }
+
+    /* get the tooltip of the shape */
+    if (!strcmp(xmlnamenode->name, "tooltip")
+	&& (lang==NULL
+	    || !strcmp(lang, gcompris_get_locale())
+	    || !strncmp(lang, gcompris_get_locale(), 2)))
+      {
+	tooltip = xmlNodeListGetString(doc, xmlnamenode->xmlChildrenNode, 1);
+      }
+
     xmlnamenode = xmlnamenode->next;
   }
 
@@ -1683,11 +1779,12 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   if(!name)
     name = xmlGetProp(xmlnode,"name");
 
+
   if(g_strcasecmp(xmlnode->name,"Shape")==0)
     {
       /* add the shape to the database */
       /* WARNING : I do not initialize the width and height since I don't need them */
-      shape = create_shape(type, name, pixmapfile, points, targetfile, x, y, 
+      shape = create_shape(type, name, tooltip, pixmapfile, points, targetfile, x, y, 
 			   (double)0, (double)0,
 			   zoomx, zoomy, position, soundfile);
 
@@ -1696,7 +1793,16 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
     } 
   else if (g_strcasecmp(xmlnode->name,"Title")==0)
     {
-      create_title(name, x, y, justification_gtk);
+      /* Readd \n is needed */
+      gchar *newname;
+
+      if(name != NULL) {
+	newname = g_strcompress(name);
+
+	g_free(name);
+
+	create_title(newname, x, y, justification_gtk, color_rgba);
+      }
     }
   
 }
@@ -1707,6 +1813,7 @@ parse_doc(xmlDocPtr doc)
 {
   xmlNodePtr node;
   GList *list;
+  GnomeCanvasItem *item;
 
   /* find <Shape> nodes and add them to the list, this just
      loops through all the children of the root of the document */
@@ -1731,7 +1838,17 @@ parse_doc(xmlDocPtr doc)
   
   g_list_free(shape_list_init);
   shape_list_init = NULL;
-  
+
+  if(current_shapelistgroup_index>0) { /* If at least on shape group */
+    item = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
+    gnome_canvas_item_hide(item); 
+    item = g_list_nth_data(shape_list_group, 0);
+    gnome_canvas_item_show(item);
+    gnome_canvas_item_hide(previous_shapelist_item); 
+    gnome_canvas_item_show(next_shapelist_item);
+    current_shapelistgroup_index = 0; 
+  }
+
   /* Loop through all the shapes and */
   /* Arrange the order (depth) of the shapes on the canvas */
   /* Depending on the xml given definition in the position property */
@@ -1789,7 +1906,7 @@ read_xml_file(char *fname)
       addedname = INT_MAX;
   else
       addedname = atoi(tmpstr);
-  printf("addedname=%d\n", addedname);
+  g_warning("addedname=%d\n", addedname);
 
   /*--------------------------------------------------*/
   /* Read ShapeBox property */
@@ -1799,7 +1916,7 @@ read_xml_file(char *fname)
       shapeBox.x = 15;
   else
       shapeBox.x = atof(tmpstr);
-  printf("shapeBox.x=%f\n", shapeBox.x);
+  g_warning("shapeBox.x=%f\n", shapeBox.x);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_y");
   /* if unspecified, use the default value */
@@ -1807,7 +1924,7 @@ read_xml_file(char *fname)
       shapeBox.y = 25;
   else
       shapeBox.y = atof(tmpstr);
-  printf("shapeBox.y=%f\n", shapeBox.y);
+  g_warning("shapeBox.y=%f\n", shapeBox.y);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_w");
   /* if unspecified, use the default value */
@@ -1815,7 +1932,7 @@ read_xml_file(char *fname)
       shapeBox.w = 80;
   else
       shapeBox.w = atof(tmpstr);
-  printf("shapeBox.w=%f\n", shapeBox.w);
+  g_warning("shapeBox.w=%f\n", shapeBox.w);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_h");
   /* if unspecified, use the default value */
@@ -1823,7 +1940,7 @@ read_xml_file(char *fname)
       shapeBox.h = 430;
   else
       shapeBox.h = atof(tmpstr);
-  printf("shapeBox.h=%f\n", shapeBox.h);
+  g_warning("shapeBox.h=%f\n", shapeBox.h);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_nb_shape_x");
   /* if unspecified, use the default value */
@@ -1831,7 +1948,7 @@ read_xml_file(char *fname)
       shapeBox.nb_shape_x = 1;
   else
       shapeBox.nb_shape_x = atoi(tmpstr);
-  printf("shapeBox.nb_shape_x=%d\n", shapeBox.nb_shape_x);
+  g_warning("shapeBox.nb_shape_x=%d\n", shapeBox.nb_shape_x);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_nb_shape_y");
   /* if unspecified, use the default value */
@@ -1839,7 +1956,7 @@ read_xml_file(char *fname)
       shapeBox.nb_shape_y = 5;
   else
       shapeBox.nb_shape_y = atoi(tmpstr);
-  printf("shapeBox.nb_shape_y=%d\n", shapeBox.nb_shape_y);
+  g_warning("shapeBox.nb_shape_y=%d\n", shapeBox.nb_shape_y);
 
 
   /* parse our document and replace old data */
@@ -1865,6 +1982,8 @@ write_shape_to_xml(xmlNodePtr xmlnode, Shape *shape)
   newxml = xmlNewChild(xmlnode,NULL,"Shape",NULL);
   /* set properties on it */
   xmlSetProp(newxml,"name",shape->name);
+  if(shape->tooltip)
+    xmlSetProp(newxml,"tooltip",shape->tooltip);
   xmlSetProp(newxml,"pixmapfile",shape->pixmapfile);
   xmlSetProp(newxml,"sound",shape->soundfile);
 
