@@ -43,7 +43,12 @@ static gchar *greetingsList[] =
 {
   "congratulation.ogg",
   "great.ogg",
-  "good.ogg"
+  "good.ogg",
+  "awesome.ogg",
+  "fantastic.ogg",
+  "waytogo.ogg",
+  "super.ogg",
+  "perfect.ogg"
 };
 #define NUMBER_OF_GREETINGS 3
 
@@ -211,6 +216,12 @@ void gcompris_display_bonus(int gamewon, int bonus_id)
   case BONUS_FLOWER :
     bonus_image("flower",gamewon);
     break;
+  case BONUS_TUX :
+    bonus_image("tux",gamewon);
+    break;
+  case BONUS_GNU :
+    bonus_image("gnu",gamewon);
+    break;
   default :
     bonus_image("smiley",gamewon);
     break;
