@@ -1,6 +1,6 @@
 /* gcompris - config.c
  *
- * Time-stamp: <2004/06/05 23:55:34 bcoudoin>
+ * Time-stamp: <2004/10/28 21:58:30 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -66,16 +66,19 @@ static gchar *linguas[] = {
   "az_AZ.UTF-8", 	N_("Azerbaijani Turkic"),
   "ca_ES.UTF-8",	N_("Catalan"),
   "cs_CZ.UTF-8",	N_("Czech"),
+  "da_DK.UTF-8", 	N_("Danish"),
   "de_DE.UTF-8", 	N_("German"),
   "el_GR.UTF-8", 	N_("Greek"),
-  "en_US.UTF-8",	N_("American English"),
-  "en_GB.UTF-8",	N_("Great Britain English"),
-  "en_CA.UTF-8",	N_("Canadian English"),
+  "en_CA.UTF-8",	N_("English (Canadian)"),
+  "en_GB.UTF-8",	N_("English (Great Britain)"),
+  "en_US.UTF-8",	N_("English (USA)"),
   "es_ES.UTF-8", 	N_("Spanish"),
   "fi_FI.UTF-8", 	N_("Finnish"),
   "fr_FR.UTF-8", 	N_("French"),
+  "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
   "he_IL.UTF-8",	N_("Hebrew"),
-  "hi_IN.UTF-8",	N_("Indian"),
+  "hi_IN.UTF-8",	N_("Indian (Hindi)"),
+  "pa_IN.UTF-8",	N_("Indian (Punjabi)"),
   "hu_HU.UTF-8",	N_("Hungarian"),
   "hr_HR.UTF-8",	N_("Croatian"),
   "it_IT.UTF-8", 	N_("Italian"),
@@ -84,7 +87,8 @@ static gchar *linguas[] = {
   "ml_IN.UTF-8",	N_("Malayalam"),
   "ms_MY.UTF-8",	N_("Malay"),
   "nl_NL.UTF-8",	N_("Dutch"),
-  "no_NO.UTF-8",	N_("Norwegian"),
+  "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
+  "nn_NO.UTF-8",	N_("Norwegian Nynorsk"),
   "pl_PL.UTF-8",	N_("Polish"),
   "pt_PT.UTF-8",	N_("Portuguese"),
   "pt_BR.UTF-8",	N_("Brazil Portuguese"),
@@ -92,10 +96,12 @@ static gchar *linguas[] = {
   "ru_RU.UTF-8",	N_("Russian"),
   "sk_SK.UTF-8",	N_("Slovak"),
   "sl_SI.UTF-8",	N_("Slovenian"),
+  "sq_AL.UTF-8",	N_("Albanian"),
   "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
   "sr_YU.UTF-8",	N_("Serbian"),
   "sv_FI.UTF-8",	N_("Swedish"),
   "tr_TR.UTF-8",	N_("Turkish"),
+  "wa_BE.UTF-8",	N_("Walloon"),
   NULL, NULL
 };
 
