@@ -1,6 +1,6 @@
 /* gcompris - gameutil.c
  *
- * Time-stamp: <2004/06/18 00:28:51 bcoudoin>
+ * Time-stamp: <2004/10/23 22:22:57 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -41,6 +41,7 @@ static char *lettersdir = "letters/";
 static GList *boards_list = NULL;
 
 static GnomeCanvasGroup *rootDialogItem = NULL;
+static GnomeCanvasItem *itemDialogText = NULL;
 static gint item_event_ok(GnomeCanvasItem *item, GdkEvent *event, DialogBoxCallBack dbcb);
 
 extern GnomeCanvas *canvas;
@@ -725,14 +726,33 @@ void item_rotate(GnomeCanvasItem *item, double angle) {
    IMPORTANT NOTE : This is designed for an item with "anchor" =  GTK_ANCHOR_CENTER
    rotation is clockwise if angle > 0 */
 void item_rotate_relative(GnomeCanvasItem *item, double angle) {
-  double r[6],t[6], x1, x2, y1, y2;
+  double x1, x2, y1, y2;
+  double cx, cy;
+  double t;
+  double r[6];
 
   gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
-  art_affine_translate( t , -(x2+x1)/2, -(y2+y1)/2 );
-  art_affine_rotate( r, angle );
-  art_affine_multiply( r, t, r);
-  art_affine_translate( t , (x2+x1)/2, (y2+y1)/2 );
-  art_affine_multiply( r, r, t);
+  cx = (x2+x1)/2;
+  cy = (y2+y1)/2;
+
+  /* Taken from anim by Yves Combe
+   * This matrix rotate around ( cx, cy )
+   * This is the result of the product:
+   *            T_{-c}             Rot (t)                 T_c
+   *
+   *       1    0   cx       cos(t) -sin(t)    0        1    0  -cx
+   *       0    1   cy  by   sin(t)  cos(t)    0   by   0    1  -cy
+   *       0    0    1         0       0       1        0    0   1
+   */
+
+  t = M_PI*angle/180.0;
+
+  r[0] = cos(t);
+  r[1] = sin(t);
+  r[2] = -sin(t);
+  r[3] = cos(t);
+  r[4] = (1-cos(t))*cx + sin(t)*cy;
+  r[5] = -sin(t)*cx + (1 - cos(t))*cy;
 
   gnome_canvas_item_affine_relative(item, r );
 }
@@ -776,8 +796,15 @@ void	item_rotate_relative_with_center(GnomeCanvasItem *item, double angle, int x
 void gcompris_dialog_close() {
 
   /* If we already running delete the previous one */
-  if(rootDialogItem)
+  if(rootDialogItem) {
+    /* WORKAROUND: There is a bug in the richtex item and we need to remove it first */
+    while (g_idle_remove_by_data (itemDialogText));
+    gtk_object_destroy (itemDialogText);
+    itemDialogText = NULL;
+
     gtk_object_destroy(GTK_OBJECT(rootDialogItem));
+  }
+  
   rootDialogItem = NULL;
 
 }
@@ -789,7 +816,6 @@ void gcompris_dialog_close() {
 void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
 {
   GcomprisBoard   *gcomprisBoard = get_current_gcompris_board();
-  GnomeCanvasItem *item_dialog = NULL;
   GnomeCanvasItem *item_text   = NULL;
   GnomeCanvasItem *item_text_ok   = NULL;
   GdkPixbuf       *pixmap_dialog = NULL;
@@ -797,11 +823,13 @@ void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
   GtkTextBuffer   *buffer;
   GtkTextTag      *txt_tag;
 
-  /* If we already running delete the previous one */
-  if(rootDialogItem)
-    gtk_object_destroy(GTK_OBJECT(rootDialogItem));
-  rootDialogItem = NULL;
+  printf("Dialog=%s\n", str);
 
+  /* If we are already running do nothing */
+  if(rootDialogItem) {
+    g_warning("Cannot run a dialog box, one is already running. Message = %s\n", str);
+    return;
+  }
 
   /* First pause the board */
   if(gcomprisBoard->plugin->pause_board != NULL)
@@ -818,7 +846,7 @@ void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
       
   pixmap_dialog = gcompris_load_skin_pixmap("dialogbox.png");
 
-  item_dialog = gnome_canvas_item_new (rootDialogItem,
+  itemDialogText = gnome_canvas_item_new (rootDialogItem,
 				       gnome_canvas_pixbuf_get_type (),
 				       "pixbuf", pixmap_dialog,
 				       "x", (double) (BOARDWIDTH - gdk_pixbuf_get_width(pixmap_dialog))/2,
@@ -839,7 +867,7 @@ void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
 
   gdk_pixbuf_unref(pixmap_dialog);
 
-  gtk_signal_connect(GTK_OBJECT(item_dialog), "event",
+  gtk_signal_connect(GTK_OBJECT(itemDialogText), "event",
 		     (GtkSignalFunc) item_event_ok,
 		     dbcb);
 
@@ -965,6 +993,21 @@ GnomeCanvasGroup *gcompris_display_difficulty_stars(GnomeCanvasGroup *parent,
   return(stars_group);
 }
 
+gchar *g_utf8_strndup(gchar* utf8text, gint n)
+{
+ gchar* result;
+
+ gint len = g_utf8_strlen(utf8text, -1);
+
+ if( n < len && n > 0 )
+   len = n;
+
+ result = g_strndup(utf8text, g_utf8_offset_to_pointer(utf8text, len) - utf8text);
+
+ return result;
+} 
+
+
 /* Local Variables: */
 /* mode:c */
 /* eval:(load-library "time-stamp") */
