@@ -35,6 +35,7 @@
 // returns a random integer in range [A,B]
 #define RAND(A,B) (A + (int)((float)(B-A+1)*rand()/(RAND_MAX+1.0)))
 
+gchar 		*g_utf8_strndup(gchar*,gint);
 
 GdkPixbuf	*gcompris_load_pixmap(char *pixmapfile);
 void		 gcompris_set_image_focus(GnomeCanvasItem *item, gboolean focus);
@@ -84,4 +85,12 @@ GdkPixbuf	*gcompris_load_pixmap_asset(gchar *dataset, gchar* categories,
 gchar		*gcompris_get_asset_file(gchar *dataset, gchar* categories, 
 					 gchar* mimetype, gchar* file);
 
+/*! \fn void		 gcompris_clone_item(GnomeCanvasItem *item, GnomeCanvasGroup *parent)
+    \brief recursive c func to clone GnomeCanvasItem
+
+    \param item The item to clone
+    \param parent for the new item
+*/
+void		 gcompris_clone_item(GnomeCanvasItem *item, GnomeCanvasGroup *parent);
+
 #endif
